src/eric7/Debugger/DebugServer.py

branch
eric7
changeset 10311
0a141f9ae677
parent 10129
d4d210405367
child 10321
4a017fdf316f
--- a/src/eric7/Debugger/DebugServer.py	Tue Nov 14 16:10:46 2023 +0100
+++ b/src/eric7/Debugger/DebugServer.py	Tue Nov 14 17:25:35 2023 +0100
@@ -918,9 +918,9 @@
             # the peer is not allowed to connect
             res = EricMessageBox.yesNo(
                 None,
-                self.tr("Connection from illegal host"),
+                self.tr("Connection from unknown host"),
                 self.tr(
                     """<p>A connection was attempted by the illegal host"""
                     """ <b>{0}</b>. Accept this connection?</p>"""
                 ).format(peerAddress),
                 icon=EricMessageBox.Warning,
@@ -918,9 +918,9 @@
                 self.tr(
-                    """<p>A connection was attempted by the illegal host"""
+                    """<p>A connection was attempted by the unknown host"""
                     """ <b>{0}</b>. Accept this connection?</p>"""
                 ).format(peerAddress),

eric ide

mercurial